@@ -9,11 +9,11 @@ RGBtoMunsell <- function( RGB, space='sRGB', maxSignal=255, adapt='Bradford', ..
     
     if( ! requireNamespace( 'spacesXYZ', quietly=TRUE ) )   return(NULL)
     
-    theSpace = spacesRGB::getRGB(space,full=FALSE)
-    if( is.null(theSpace) ) return(NULL)
+    #theSpace = spacesRGB::getRGB(space,full=FALSE)
+    #if( is.null(theSpace) ) return(NULL)
     
     # Convert RGB input into CIE XYZ and xyY coordinates
-    XYZ = spacesRGB::XYZfromRGB( RGB, space=space, which='scene', maxSignal=maxSignal )$XYZ  # for white, Y=100
+    XYZ = spacesRGB::XYZfromRGB( RGB, space=space, which='display', maxSignal=maxSignal )$XYZ  # for white, Y=100
     if( is.null(XYZ) )  return(NULL)
         
     #   XYZ = 100 * XYZ
@@ -21,7 +21,7 @@ RGBtoMunsell <- function( RGB, space='sRGB', maxSignal=255, adapt='Bradford', ..
     xyY = spacesXYZ::xyYfromXYZ(XYZ)
 
     # adapt xyY from the RGB space white to C
-    white       = theSpace$whiteXYZ
+    white       = spacesRGB::getWhiteXYZ( space, which='display')  # theSpace$whiteXYZ
     white.C     = spacesXYZ::XYZfromxyY( c( p.xyC['NBS',], 100 ) )
 
     theCAT      = spacesXYZ::CAT( white, white.C, method=adapt )
@@ -42,8 +42,8 @@ MunsellToRGB <- function( MunsellSpec, space='sRGB', maxSignal=255, adapt='Bradf
     
     if( ! requireNamespace( 'spacesXYZ', quietly=TRUE ) )   return(NULL)
     
-    theSpace = spacesRGB::getRGB(space,full=FALSE)
-    if( is.null(theSpace) ) return(NULL)
+    #theSpace = spacesRGB::getRGB(space,full=FALSE)
+    #if( is.null(theSpace) ) return(NULL)
         
     # Convert from Munsell notation to CIE coordiantes
     tmp = MunsellToxyY( MunsellSpec, ... )
@@ -56,8 +56,10 @@ MunsellToRGB <- function( MunsellSpec, space='sRGB', maxSignal=255, adapt='Bradf
 
     # adapt xyY from C to the RGB space white
     white.C =   spacesXYZ::XYZfromxyY( c( p.xyC['NBS',], 100 ) )    
-    white   =   theSpace$whiteXYZ
-
+    
+    white   =   spacesRGB::getWhiteXYZ( space, which='display')     #theSpace$whiteXYZ
+    if( is.null(white) )    return(NULL)
+    
     theCAT      = spacesXYZ::CAT( white.C, white, method=adapt )
     
     xyY.adapted = spacesXYZ::adaptxyY( theCAT, xyY )
@@ -65,7 +67,7 @@ MunsellToRGB <- function( MunsellSpec, space='sRGB', maxSignal=255, adapt='Bradf
     XYZ.adapted = spacesXYZ::XYZfromxyY( xyY.adapted )
 
     # Convert CIE XYZ coordinates to RGB coordinates
-    out = cbind( out, spacesRGB::RGBfromXYZ( XYZ.adapted, space=space, which='scene', maxSignal=maxSignal ) )
+    out = cbind( out, spacesRGB::RGBfromXYZ( XYZ.adapted, space=space, which='display', maxSignal=maxSignal ) )
 
     rnames  = tmp$SAMPLE_NAME
     if( anyDuplicated(rnames) ) rnames = 1:nrow(out)
